getHostname.System.RdRetrieves the computer name of the current host.
## Static method (use this):
## System$getHostname(...)
## Don't use the below:
# S3 method for System
getHostname(static, ...)Returns a character string.
First, this function checks the system environment variables HOST,
HOSTNAME, and COMPUTERNAME.
Second, it checks Sys.info()["nodename"] for host name details.
Finally, it tries to query the system command uname -n.
*getUsername().